/*****************************************************************
 * Fritz Fun                                                     *
 * Created by Jan-Michael Brummer                                *
 * All parts are distributed under the terms of GPL. See COPYING *
 *****************************************************************/

/**
 * \file about-dialog.c
 * \brief About dialog
 */

#include <ffgtk.h>

/**
 * \brief About url hook - callback if link in about window is clicked
 * \param psAbout about dialog pointer
 * \param pnLink link clicked
 * \param pData user data (unused)
 */
static void aboutUrlHook( GtkAboutDialog *psAbout, const char *pnLink, gpointer pData ) {
	gchar *pnExec = NULL;

	/* safety check: link != null */
	assert( pnLink != NULL );

	/* create execution command line for g_spawn */
	pnExec = g_strdup_printf( "xdg-open %s", pnLink );

	/* execute xdg-open, the standard ui-independent way in opening the default browser */
	g_spawn_command_line_async( pnExec, NULL );

	/* free command line */
	g_free( pnExec );
}

/**
 * \brief About dialog
 */
void aboutDialog( void ) {
	static GdkPixbuf *psAboutLogo = NULL;
	const gchar *apnAuthors[] = {
		"Jan-Michael Brummer <jan.brummer@tabos.org>",
		"",
		"Patches by:",
		"Christian von Behren <admin@grizzlysoft.de>",
		"Whoopie",
		"Michael Burkhard",
		"Bastian Kleineidam",
		"Louis Lagendijk",
		"Marco Schuh",
		NULL
	};
	const gchar *apnDocumenters[] = {
		"Jan-Michael Brummer <jan.brummer@tabos.org>",
		NULL
	};
	char *pnTranslators =
		"Jan-Michael Brummer <jan.brummer@tabos.org>\n"
		"Louis Lagendijk";
	char anVersion[ 256 ];

	/* set url callback function */
	gtk_about_dialog_set_url_hook( aboutUrlHook, NULL, NULL );

	if ( psAboutLogo == NULL ) {
		psAboutLogo = gdk_pixbuf_new_from_file( SHAREDIR "ffgtk.png", NULL );
	}

	snprintf( anVersion, sizeof( anVersion ), "%s\n%s", PACKAGE_VERSION, anSvnRevision );

	/* create about dialog */
	gtk_show_about_dialog( NULL,
		"name", PACKAGE_NAME,
	    "logo", psAboutLogo,
		//"version", anVersion,
		"version", PACKAGE_VERSION,
		"copyright", "(C) 2008-2010, Jan-Michael Brummer <jan.brummer@tabos.org>",
		"comments", _( "FRITZ!Box Fax-Software and Call-Monitor\nDedicated to my father" ),
	    "license",
			_( "This program is free software; you can redistribute it and/or modify it under the terms of the GNU "
	        "General Public License Version 2 as published by the Free Software Foundation\n\n"
			"This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; "
	        "without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. "
	        "See the GNU General Public License for more details.\n\n"
			"You should have received a copy of the GNU General Public License along with this program; "
	        "if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
	        "MA 02110-1301, USA" ),
	    "wrap-license", TRUE,
		"authors", apnAuthors,
		"documenters", apnDocumenters,
		"translator-credits", g_locale_to_utf8( pnTranslators, -1, 0, 0, 0 ),
		"website", PACKAGE_BUGREPORT,
		NULL );
}
