/*****************************************************************
 * Fritz Fun                                                     *
 * Created by Jan-Michael Brummer                                *
 * All parts are distributed under the terms of GPL. See COPYING *
 *****************************************************************/

/**
 * \file faxbox.c
 * \brief Contains all function needed for fax box support
 */

#include <ffgtk.h>

/**
 * \brief Fax box open callback
 * \param psModel tree model
 * \param psPath tree path
 */
void faxBoxOpen( GtkTreeModel *psModel, GtkTreePath *psPath ) {
	GtkTreeIter sSelectedIter;
	GValue sFile = { 0 };

	if ( gtk_tree_model_get_iter( psModel, &sSelectedIter, psPath ) ) {
		gtk_tree_model_get_value( psModel, &sSelectedIter, 6, &sFile );

		Debug( KERN_DEBUG, "TODO: open sFile: [%s]\n", g_value_get_string( &sFile ) );
		if ( routerLoadFaxFile( getActiveProfile(), g_value_get_string( &sFile ) ) == 0 ) {
#ifdef __MACOSX__
			g_spawn_command_line_async( "open /tmp/fax", NULL );
#else
			g_spawn_command_line_async( "xdg-open /tmp/fax", NULL );
#endif
		}
		
		g_value_unset( &sFile );
	}
}

/**
 * \brief Fax box delete callback
 * \param psModel tree model
 * \param psPath tree path
 */
void faxBoxDelete( GtkTreeModel *psModel, GtkTreePath *psPath ) {
	GtkTreeIter sSelectedIter;
	GValue sFile = { 0 };

	if ( gtk_tree_model_get_iter( psModel, &sSelectedIter, psPath ) ) {
		gtk_tree_model_get_value( psModel, &sSelectedIter, 6, &sFile );

		routerDeleteFaxFile( getActiveProfile(), g_value_get_string( &sFile ) );

		g_value_unset( &sFile );
	}
}
